@@ -3,7 +3,7 @@
 /*
     bqaudioio
 
-    Copyright 2007-2016 Particular Programs Ltd.
+    Copyright 2007-2021 Particular Programs Ltd.
 
     Permission is hereby granted, free of charge, to any person
     obtaining a copy of this software and associated documentation
@@ -72,6 +72,13 @@ ResamplerWrapper::ResamplerWrapper(ApplicationPlaybackSource *source) :
     
     m_channels = m_source->getApplicationChannelCount();
 
+    {
+        ostringstream os;
+        os << "ResamplerWrapper: Initial source rate " << m_sourceRate
+           << " and channels " << m_channels;
+        Log::log(os.str());
+    }
+    
     reconstructResampler();
 }
 
@@ -87,8 +94,25 @@ void
 ResamplerWrapper::changeApplicationSampleRate(int newRate)
 {
     lock_guard<mutex> guard(m_mutex);
+
+    {
+        ostringstream os;
+        os << "ResamplerWrapper: Source rate changing from " << m_sourceRate
+           << " to " << newRate;
+        Log::log(os.str());
+    }
+
     m_sourceRate = newRate;
-    setupBuffersFor(defaultMaxBufferSize);
+
+    if (m_sourceRate == 0) {
+        Log::log("ResamplerWrapper::changeApplicationSampleRate: Note: "
+                 "Source rate is zero, won't be resampling");
+    } else if (m_sourceRate == m_targetRate) {
+        Log::log("ResamplerWrapper::changeApplicationSampleRate: Note: "
+                 "Source rate is equal to target rate, won't be resampling");
+    }
+    
+    checkBuffersFor(defaultMaxBufferSize);
 }
 
 std::string
@@ -117,9 +141,11 @@ ResamplerWrapper::getApplicationChannelCount() const
 void
 ResamplerWrapper::setSystemPlaybackBlockSize(int sz)
 {
-    cerr << "NOTE: ResamplerWrapper::setSystemPlaybackBlockSize called "
-         << "with size = " << sz << "; not passing to wrapped source, as "
-         << "actual block size will vary" << endl;
+    ostringstream os;
+    os << "NOTE: ResamplerWrapper::setSystemPlaybackBlockSize called "
+       << "with size = " << sz << "; not passing to wrapped source, as "
+       << "actual block size will vary";
+    Log::log(os.str());
 }
 
 void
@@ -130,6 +156,12 @@ ResamplerWrapper::setSystemPlaybackSampleRate(int rate)
         m_targetRate = rate;
     }
 
+    ostringstream os;
+    os << "NOTE: ResamplerWrapper::setSystemPlaybackSampleRate called "
+       << "with rate = " << rate << "; not passing to wrapped source, as "
+       << "we're doing the resampling";
+    Log::log(os.str());
+
     // We do the resampling around here - pretend to our own source
     // that their preferred rate is always the same as the device's
     m_source->setSystemPlaybackSampleRate(m_sourceRate);
@@ -152,7 +184,17 @@ ResamplerWrapper::setSystemPlaybackChannelCount(int c)
 void
 ResamplerWrapper::setSystemPlaybackLatency(int latency)
 {
-    m_source->setSystemPlaybackLatency(latency);
+    // The latency is provided to us in samples at m_targetRate, but
+    // we need to report it to the source in samples at
+    // m_sourceRate. (This does mean it might not be exact)
+
+    if (m_sourceRate != 0 && m_targetRate != 0 &&
+        m_sourceRate != m_targetRate) {
+        double atSourceRate = (double(latency) / m_targetRate) * m_sourceRate;
+        m_source->setSystemPlaybackLatency(int(round(atSourceRate)));
+    } else {
+        m_source->setSystemPlaybackLatency(latency);
+    }
 }
 
 void
@@ -200,30 +242,41 @@ ResamplerWrapper::reconstructResampler()
         deconstructResampler();
     }
         
+    if (m_channels == 0) {
+        Log::log("ResamplerWrapper::reconstructResampler: Channel count is 0; not constructing a resampler until the system calls back with a non-zero channel count");
+        return;
+    }
+    
     Resampler::Parameters params;
     params.quality = Resampler::FastestTolerable;
+    /*!!! to be restored following resampler merge
+    params.dynamism = Resampler::RatioMostlyFixed;
+    params.ratioChange = Resampler::SuddenRatioChange;
+    */
     params.maxBufferSize = defaultMaxBufferSize;
     if (m_sourceRate != 0) {
         params.initialSampleRate = m_sourceRate;
     }
 
+    ostringstream os;
+    os << "ResamplerWrapper::reconstructResampler: Creating resampler with "
+       << "initial source rate " << params.initialSampleRate
+       << ", buffer size " << defaultMaxBufferSize
+       << ", channel count " << m_channels;
+    Log::log(os.str());
+
     m_resampler = new Resampler(params, m_channels);
     
     m_ptrs = new float *[m_channels];
-    setupBuffersFor(defaultMaxBufferSize);
+    checkBuffersFor(defaultMaxBufferSize);
 }
 
 void
-ResamplerWrapper::setupBuffersFor(int nframes)
+ResamplerWrapper::checkBuffersFor(int nframes)
 {
     if (m_sourceRate == 0) return;
     if (m_sourceRate == m_targetRate) return;
 
-#ifdef DEBUG_RESAMPLER_WRAPPER
-    cerr << "ResamplerWrapper::setupBuffersFor: Source rate "
-         << m_sourceRate << " -> target rate " << m_targetRate << endl;
-#endif
-
     int slack = 100;
     double ratio = double(m_targetRate) / double(m_sourceRate);
     if (ratio > 50.0) {
@@ -231,12 +284,16 @@ ResamplerWrapper::setupBuffersFor(int nframes)
     }
     int newResampledSize = nframes + slack;
     int newInSize = int(newResampledSize / ratio);
-
-#ifdef DEBUG_RESAMPLER_WRAPPER
-    cerr << "newResampledSize = " << newResampledSize << ", newInSize = " << newInSize << endl;
-#endif
     
     if (!m_resampled || newResampledSize > m_resampledSize) {
+        {
+            ostringstream os;
+            os << "ResamplerWrapper::checkBuffersFor: Source rate "
+               << m_sourceRate << " -> target rate " << m_targetRate
+               << "; newResampledSize = " << newResampledSize
+               << ", newInSize = " << newInSize;
+            Log::log(os.str());
+        }
         m_resampled = reallocate_and_zero_extend_channels
             (m_resampled,
              m_channels, m_resampledSize,
@@ -262,7 +319,7 @@ ResamplerWrapper::getSourceSamples(float *const *samples, int nchannels, int nfr
     cerr << "ResamplerWrapper::getSourceSamples(" << nframes << "): source rate = " << m_sourceRate << ", target rate = " << m_targetRate << ", channels = " << m_channels << endl;
 #endif
     
-    setupBuffersFor(nframes);
+    checkBuffersFor(nframes);
 
     if (m_sourceRate == 0) {
         v_zero_channels(samples, nchannels, nframes);
@@ -270,7 +327,10 @@ ResamplerWrapper::getSourceSamples(float *const *samples, int nchannels, int nfr
     }
     
     if (nchannels != m_channels) {
-        cerr << "nchannels = " << nchannels << ", m_channels = " << m_channels << endl;
+        ostringstream os;
+        os << "ERROR: ResamplerWrapper::getSourceSamples: nchannels = "
+           << nchannels << " but m_channels = " << m_channels;
+        Log::log(os.str());
         throw std::logic_error("Different number of channels requested than ResamplerWrapper declared");
     }
     
@@ -284,7 +344,7 @@ ResamplerWrapper::getSourceSamples(float *const *samples, int nchannels, int nfr
     int req = int(round(reqResampled / ratio)) + 1;
 
     int received = m_source->getSourceSamples(m_in, m_channels, req);
-    
+
     for (int i = 0; i < m_channels; ++i) {
         m_ptrs[i] = m_resampled[i] + m_resampledFill;
     }
