@@ -444,12 +444,18 @@ private:
         // was only added the same 5.14 release!
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
-        NodeSet remaining = NodeSet::fromList(children);
         Nodes ordered = orderedSiblingsOf(children[0]);
-        remaining.subtract(NodeSet::fromList(ordered));
-        foreach (Node n, remaining) ordered.push_back(n);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        NodeSet remainingSet(children.begin(), children.end()); 
+        NodeSet orderedSet(ordered.begin(), ordered.end());
+#else
+        NodeSet remainingSet = NodeSet::fromList(children);
+        NodeSet orderedSet = NodeSet::fromList(ordered);
+#endif
+        remainingSet.subtract(orderedSet);
+        foreach (Node n, remainingSet) ordered.push_back(n);
         DQ_DEBUG << "orderedChildrenOf: Node " << node << " has " << ordered.size()
-              << " children: " << ordered << endl;
+                 << " children: " << ordered << endl;
         return ordered;
     }
         
