@@ -44,9 +44,11 @@ Preferences::Preferences() :
     m_omitRecentTemps(true),
     m_tempDirRoot(""),
     m_fixedSampleRate(0),
+    m_recordMono(false),
     m_resampleOnLoad(false),
     m_gapless(true),
     m_normaliseAudio(false),
+    m_finerTimeStretch(true),
     m_viewFontSize(10),
     m_backgroundMode(BackgroundFromTheme),
     m_timeToTextMode(TimeToTextMs),
@@ -67,9 +69,11 @@ Preferences::Preferences() :
         (settings.value("window-type", int(HanningWindow)).toInt());
     m_runPluginsInProcess = settings.value("run-vamp-plugins-in-process", true).toBool();
     m_fixedSampleRate = settings.value("fixed-sample-rate", 0).toDouble();
+    m_recordMono = settings.value("record-mono", false).toBool();
     m_resampleOnLoad = settings.value("resample-on-load", false).toBool();
     m_gapless = settings.value("gapless", true).toBool();
     m_normaliseAudio = settings.value("normalise-audio", false).toBool();
+    m_finerTimeStretch = settings.value("finer-timestretch", true).toBool();
     m_backgroundMode = BackgroundMode
         (settings.value("background-mode", int(BackgroundFromTheme)).toInt());
     m_timeToTextMode = TimeToTextMode
@@ -100,9 +104,11 @@ Preferences::getProperties() const
     props.push_back("Window Type");
     props.push_back("Resample Quality");
     props.push_back("Omit Temporaries from Recent Files");
+    props.push_back("Record Mono");
     props.push_back("Resample On Load");
     props.push_back("Use Gapless Mode");
     props.push_back("Normalise Audio");
+    props.push_back("Use Finer Time Stretch");
     props.push_back("Fixed Sample Rate");
     props.push_back("Temporary Directory Root");
     props.push_back("Background Mode");
@@ -138,9 +144,15 @@ Preferences::getPropertyLabel(const PropertyName &name) const
     if (name == "Normalise Audio") {
         return tr("Normalise audio signal when reading from audio file");
     }
+    if (name == "Use Finer Time Stretch") {
+        return tr("Use fine-quality time stretcher");
+    }
     if (name == "Omit Temporaries from Recent Files") {
         return tr("Omit temporaries from Recent Files menu");
     }
+    if (name == "Record Mono") {
+        return tr("Mix recorded channels to mono");
+    }
     if (name == "Resample On Load") {
         return tr("Resample mismatching files on import");
     }
@@ -198,9 +210,15 @@ Preferences::getPropertyType(const PropertyName &name) const
     if (name == "Normalise Audio") {
         return ToggleProperty;
     }
+    if (name == "Use Finer Time Stretch") {
+        return ToggleProperty;
+    }
     if (name == "Omit Temporaries from Recent Files") {
         return ToggleProperty;
     }
+    if (name == "Record Mono") {
+        return ToggleProperty;
+    }
     if (name == "Resample On Load") {
         return ToggleProperty;
     }
@@ -551,6 +569,19 @@ Preferences::setTemporaryDirectoryRoot(QString root)
     }
 }
 
+void
+Preferences::setRecordMono(bool mono)
+{
+    if (m_recordMono != mono) {
+        m_recordMono = mono;
+        QSettings settings;
+        settings.beginGroup("Preferences");
+        settings.setValue("record-mono", mono);
+        settings.endGroup();
+        emit propertyChanged("Record Mono");
+    }
+}
+
 void
 Preferences::setResampleOnLoad(bool resample)
 {
@@ -603,6 +634,19 @@ Preferences::setNormaliseAudio(bool norm)
     }
 }
 
+void
+Preferences::setFinerTimeStretch(bool finer)
+{
+    if (m_finerTimeStretch != finer) {
+        m_finerTimeStretch = finer;
+        QSettings settings;
+        settings.beginGroup("Preferences");
+        settings.setValue("finer-timestretch", finer);
+        settings.endGroup();
+        emit propertyChanged("Use Finer Time Stretch");
+    }
+}
+
 void
 Preferences::setBackgroundMode(BackgroundMode mode)
 {
