@@ -131,7 +131,7 @@ private:
                     // phase compared to the test signal
 
                     maxLimit = 0.1;
-                    rmsLimit = 0.05;
+                    rmsLimit = 0.07;
 
                 } else {
 
@@ -178,7 +178,7 @@ private:
 
                 // all mp3 figures are worse when not normalising
                 maxLimit = 0.1;
-                rmsLimit = 0.05;
+                rmsLimit = 0.07;
 
             } else {
 
@@ -425,10 +425,8 @@ private slots:
             // "something else" otherwise.
             
             if (gapless) {
-                if (format == "aac"
-#ifdef Q_OS_WIN
-                    || (format == "mp3" && (readRate != fileRate))
-#endif
+                if (format == "aac" ||
+                    (format == "mp3" && (readRate != fileRate))
                     ) {
                     // ouch!
                     if (offset == -1) offset = 0;
