@@ -34,7 +34,7 @@
 #endif
 
 //#define DEBUG_DSSI 1
-#define DEBUG_DSSI_PROCESS 1
+//#define DEBUG_DSSI_PROCESS 1
 
 #define EVENT_BUFFER_SIZE 1023
 
