@@ -23,6 +23,7 @@
 
 #include "base/ProgressReporter.h"
 #include "base/RealTime.h"
+#include "base/StringBits.h"
 
 #include "data/model/SparseOneDimensionalModel.h"
 #include "data/model/SparseTimeValueModel.h"
@@ -35,6 +36,7 @@
 #include "data/fileio/FileSource.h"
 #include "data/fileio/CachedFile.h"
 #include "data/fileio/FileFinder.h"
+#include "data/fileio/TextTest.h"
 
 #include <dataquay/BasicStore.h>
 #include <dataquay/PropertyObject.h>
@@ -790,19 +792,22 @@ RDFImporterImpl::fillModel(ModelId modelId,
 }
 
 RDFImporter::RDFDocumentType
-RDFImporter::identifyDocumentType(QString url)
+RDFImporter::identifyDocumentType(QUrl url)
 {
     bool haveAudio = false;
     bool haveAnnotations = false;
     bool haveRDF = false;
 
-    BasicStore *store = nullptr;
+    if (!isPlausibleDocumentOfAnyKind(url)) {
+        return NotRDF;
+    }
 
+    BasicStore *store = nullptr;
+    
     // This is not expected to return anything useful, but if it does
     // anything at all then we know we have RDF
     try {
-        //!!! non-local document?
-        store = BasicStore::load(QUrl(url));
+        store = BasicStore::load(url);
         Triple t = store->matchOnce(Triple());
         if (t != Triple()) haveRDF = true;
     } catch (std::exception &) {
@@ -880,3 +885,9 @@ RDFImporter::identifyDocumentType(QString url)
     return OtherRDFDocument;
 }
 
+bool
+RDFImporter::isPlausibleDocumentOfAnyKind(QUrl url)
+{
+    return TextTest::isApparentTextDocument(FileSource(url));
+}
+
