@@ -45,6 +45,7 @@ SliceLayer::SliceLayer() :
     m_gain(1.0),
     m_minbin(0),
     m_maxbin(0),
+    m_cachedScaleFactor(1),
     m_currentf0(0),
     m_currentf1(0)
 {
@@ -200,6 +201,11 @@ SliceLayer::getXForScalePoint(const LayerGeometryProvider *v,
 
     int pw = v->getPaintWidth();
     int origin = m_xorigins[v->getId()];
+
+    if (v->getScaleFactor() != m_cachedScaleFactor) {
+        origin = (origin * v->getScaleFactor()) / m_cachedScaleFactor;
+    }
+    
     int w = pw - origin;
     if (w < 1) w = 1;
 
@@ -276,6 +282,10 @@ SliceLayer::getScalePointForX(const LayerGeometryProvider *v,
     int pw = v->getPaintWidth();
     int origin = m_xorigins[v->getId()];
 
+    if (v->getScaleFactor() != m_cachedScaleFactor) {
+        origin = (origin * v->getScaleFactor()) / m_cachedScaleFactor;
+    }
+
     int w = pw - origin;
     if (w < 1) w = 1;
 
@@ -335,13 +345,13 @@ SliceLayer::getValueALQuantity() const
     // UnitDatabase::Quantity::Other, because they have already
     // decided they're doing dB somehow
     
-    AudioLevel::Quantity quantity = AudioLevel::Quantity::RootPower;
     UnitDatabase::Quantity uq = getValueQuantity();
     switch (uq) {
     case UnitDatabase::Quantity::Power: return AudioLevel::Quantity::Power;
     case UnitDatabase::Quantity::RootPower: return AudioLevel::Quantity::RootPower;
     case UnitDatabase::Quantity::Other: return AudioLevel::Quantity::RootPower;
     }
+    return AudioLevel::Quantity::RootPower;
 }
 
 double
@@ -355,6 +365,12 @@ SliceLayer::getYForValue(const LayerGeometryProvider *v, double value, double &n
 
     int yorigin = m_yorigins[v->getId()];
     int h = m_heights[v->getId()];
+
+    if (v->getScaleFactor() != m_cachedScaleFactor) {
+        yorigin = (yorigin * v->getScaleFactor()) / m_cachedScaleFactor;
+        h = (h * v->getScaleFactor()) / m_cachedScaleFactor;
+    }
+    
     double thresh = getThresholdDb();
 
     double y = 0.0;
@@ -413,6 +429,12 @@ SliceLayer::getValueForY(const LayerGeometryProvider *v, double y) const
 
     int yorigin = m_yorigins[v->getId()];
     int h = m_heights[v->getId()];
+
+    if (v->getScaleFactor() != m_cachedScaleFactor) {
+        yorigin = (yorigin * v->getScaleFactor()) / m_cachedScaleFactor;
+        h = (h * v->getScaleFactor()) / m_cachedScaleFactor;
+    }
+
     double thresh = getThresholdDb();
 
     if (h <= 0) return value;
@@ -497,14 +519,21 @@ SliceLayer::paint(LayerGeometryProvider *v, QPainter &paint, QRect rect) const
 
     int xorigin = getVerticalScaleWidth(v, true, paint) + 1;
     m_xorigins[v->getId()] = xorigin; // for use in getFeatureDescription
-    
+
+/* comment out while testing simpler variant below, to try to
+ * understand why the crosshair coords are wrong
+
     int yorigin = v->getPaintHeight() - getHorizontalScaleHeight(v, paint) -
         paint.fontMetrics().height();
     int h = yorigin - paint.fontMetrics().height() - 8;
-
+*/
+    int yorigin = v->getPaintHeight() - v->scalePixelSize(35);
+    int h = yorigin - v->scalePixelSize(20);
+    
     m_yorigins[v->getId()] = yorigin; // for getYForValue etc
     m_heights[v->getId()] = h;
-
+    m_cachedScaleFactor = v->getScaleFactor();
+    
     if (h <= 0) return;
 
     QPainterPath path;
@@ -541,9 +570,14 @@ SliceLayer::paint(LayerGeometryProvider *v, QPainter &paint, QRect rect) const
     getBiasCurve(curve);
     int cs = int(curve.size());
 
+    int modelWidth = sliceableModel->getWidth();
+    
     for (int col = col0; col <= col1; ++col) {
+        if (col < 0) continue;
+        if (col >= modelWidth) break;
         DenseThreeDimensionalModel::Column column =
             sliceableModel->getColumn(col);
+        if (column.size() == 0) continue;
         for (int bin = 0; bin < mh; ++bin) {
             float value = column[bin0 + bin];
             if (bin < cs) value *= curve[bin];
@@ -715,7 +749,8 @@ SliceLayer::getVerticalScaleWidth(LayerGeometryProvider *, bool, QPainter &paint
         width = std::max(paint.fontMetrics().width("0.0") + 13,
                          paint.fontMetrics().width("x10-10"));
     } else {
-        width = std::max(paint.fontMetrics().width(tr("0dB")),
+        width = std::max(std::max(paint.fontMetrics().width(tr("0dB")),
+                                  paint.fontMetrics().width(tr("-160"))),
                          paint.fontMetrics().width(tr("-Inf"))) + 13;
     }
     return width;
@@ -874,7 +909,7 @@ SliceLayer::getPropertyRangeAndValue(const PropertyName &name,
 
     } else if (name == "Threshold") {
         
-        *min = -80;
+        *min = getMinThresholdDb();
         *max = 0;
 
         *deflt = int(round(AudioLevel::quantity_to_dB(m_initialThreshold, sort)));
@@ -989,7 +1024,8 @@ SliceLayer::getNewPropertyRangeMapper(const PropertyName &name) const
         return new LinearRangeMapper(-50, 50, -25, 25, tr("dB"));
     }
     if (name == "Threshold") {
-        return new LinearRangeMapper(-80, 0, -80, 0, tr("dB"));
+        float min = getMinThresholdDb();
+        return new LinearRangeMapper(min, 0, min, 0, tr("dB"));
     }
     return SingleColourLayer::getNewPropertyRangeMapper(name);
 }
@@ -1002,7 +1038,7 @@ SliceLayer::setProperty(const PropertyName &name, int value)
     if (name == "Gain") {
         setGain(AudioLevel::dB_to_quantity(value, sort));
     } else if (name == "Threshold") {
-        if (value == -80) setThreshold(0.0f);
+        if (value <= getMinThresholdDb()) setThreshold(0.0f);
         setThreshold(AudioLevel::dB_to_quantity(value, sort));
     } else if (name == "Colour" && usesSolidColour()) {
         setFillColourMap(value);
@@ -1106,13 +1142,27 @@ SliceLayer::setGain(float gain)
     emit layerParametersChanged();
 }
 
+float
+SliceLayer::getMinThresholdDb() const
+{
+    AudioLevel::Quantity sort = getValueALQuantity();
+    if (sort == AudioLevel::Quantity::Power) {
+        return -80.f;
+    } else {
+        return -160.f;
+    }
+}
+
 float
 SliceLayer::getThresholdDb() const
 {
     AudioLevel::Quantity sort = getValueALQuantity();
-    if (m_threshold == 0.0) return -80.f;
-    float db = float(AudioLevel::quantity_to_dB(m_threshold, sort));
-    return db;
+    if (m_threshold == 0.0) {
+        return getMinThresholdDb();
+    } else {
+        float db = float(AudioLevel::quantity_to_dB(m_threshold, sort));
+        return db;
+    }
 }
 
 int
