@@ -20,6 +20,7 @@
 #include "base/Profiler.h"
 #include "base/RangeMapper.h"
 #include "base/Strings.h"
+#include "base/ScaleTickIntervals.h"
 
 #include "ColourDatabase.h"
 #include "PaintAssistant.h"
@@ -46,6 +47,7 @@ WaveformLayer::WaveformLayer() :
     SingleColourLayer(),
     m_gain(1.0f),
     m_autoNormalize(false),
+    m_oversampling(true),
     m_showMeans(true),
     m_channelMode(SeparateChannels),
     m_channel(-1),
@@ -119,6 +121,7 @@ WaveformLayer::getProperties() const
     list.push_back("Scale");
     list.push_back("Gain");
     list.push_back("Normalize Visible Area");
+    list.push_back("Show Oversampling");
     if (m_channelCount > 1 && m_channel == -1) {
         list.push_back("Channels");
     }
@@ -132,6 +135,7 @@ WaveformLayer::getPropertyLabel(const PropertyName &name) const
     if (name == "Scale") return tr("Scale");
     if (name == "Gain") return tr("Gain");
     if (name == "Normalize Visible Area") return tr("Normalize Visible Area");
+    if (name == "Show Oversampling") return tr("Interpolate");
     if (name == "Channels") return tr("Channels");
     return SingleColourLayer::getPropertyLabel(name);
 }
@@ -140,6 +144,7 @@ QString
 WaveformLayer::getPropertyIconName(const PropertyName &name) const
 {
     if (name == "Normalize Visible Area") return "normalise";
+    if (name == "Show Oversampling") return "interpolate";
     return "";
 }
 
@@ -148,6 +153,7 @@ WaveformLayer::getPropertyType(const PropertyName &name) const
 {
     if (name == "Gain") return RangeProperty;
     if (name == "Normalize Visible Area") return ToggleProperty;
+    if (name == "Show Oversampling") return ToggleProperty;
     if (name == "Channels") return ValueProperty;
     if (name == "Scale") return ValueProperty;
     return SingleColourLayer::getPropertyType(name);
@@ -158,6 +164,7 @@ WaveformLayer::getPropertyGroupName(const PropertyName &name) const
 {
     if (name == "Gain" ||
         name == "Normalize Visible Area" ||
+        name == "Show Oversampling" ||
         name == "Scale") return tr("Scale");
     return QString();
 }
@@ -188,6 +195,11 @@ WaveformLayer::getPropertyRangeAndValue(const PropertyName &name,
         val = (m_autoNormalize ? 1 : 0);
         *deflt = 0;
 
+    } else if (name == "Show Oversampling") {
+
+        val = (m_oversampling ? 1 : 0);
+        *deflt = 1;
+
     } else if (name == "Channels") {
 
         *min = 0;
@@ -251,6 +263,8 @@ WaveformLayer::setProperty(const PropertyName &name, int value)
         setGain(AudioLevel::dB_to_voltage(value));
     } else if (name == "Normalize Visible Area") {
         setAutoNormalize(value ? true : false);
+    } else if (name == "Show Oversampling") {
+        setShowOversampledLines(value ? true : false);
     } else if (name == "Channels") {
         if (value == 1) setChannelMode(MixChannels);
         else if (value == 2) setChannelMode(MergeChannels);
@@ -286,6 +300,15 @@ WaveformLayer::setAutoNormalize(bool autoNormalize)
     emit layerParametersChanged();
 }
 
+void
+WaveformLayer::setShowOversampledLines(bool oversample)
+{
+    if (m_oversampling == oversample) return;
+    m_oversampling = oversample;
+    m_cacheValid = false;
+    emit layerParametersChanged();
+}
+
 void
 WaveformLayer::setShowMeans(bool showMeans)
 {
@@ -834,6 +857,7 @@ WaveformLayer::getOversampledRanges(int minChannel, int maxChannel,
         for (float v: oversampled) {
             RangeSummarisableTimeValueModel::Range r;
             r.sample(v);
+            r.setAbsmean(fabsf(v));
             rr.push_back(r);
         }
         ranges.push_back(rr);
@@ -1157,21 +1181,26 @@ WaveformLayer::paintChannel(LayerGeometryProvider *v,
     } else {
         paint->setPen(QPen(midColour, penWidth));
     }
-    paint->drawPath(waveformPath);
 
-    if (!clipPath.isEmpty()) {
-        paint->save();
-        paint->setPen(QPen(ColourDatabase::getInstance()->
-                           getContrastingColour(m_colour), penWidth));
-        paint->drawPath(clipPath);
-        paint->restore();
-    }
+    if (v->getZoomLevel().zone == ZoomLevel::FramesPerPixel ||
+        m_oversampling) {
+        
+        paint->drawPath(waveformPath);
 
-    if (!meanPath.isEmpty()) {
-        paint->save();
-        paint->setPen(QPen(midColour, penWidth));
-        paint->drawPath(meanPath);
-        paint->restore();
+        if (!clipPath.isEmpty()) {
+            paint->save();
+            paint->setPen(QPen(ColourDatabase::getInstance()->
+                               getContrastingColour(m_colour), penWidth));
+            paint->drawPath(clipPath);
+            paint->restore();
+        }
+
+        if (!meanPath.isEmpty()) {
+            paint->save();
+            paint->setPen(QPen(midColour, penWidth));
+            paint->drawPath(meanPath);
+            paint->restore();
+        }
     }
     
     if (!individualSamplePoints.empty()) {
@@ -1498,7 +1527,19 @@ WaveformLayer::getVerticalScaleWidth(LayerGeometryProvider *, bool, QPainter &pa
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
     if (m_scale == LinearScale) {
-        return paint.fontMetrics().width("0.0") + 13;
+        QString sampleText = "0.0";
+        if (m_gain != 1.f) {
+            int n = int(ceil(log10(m_gain)));
+            if (n > 2) {
+                sampleText = "0.0e+00";
+            } else {
+                while (n > 0) {
+                    sampleText += "0";
+                    --n;
+                }
+            }
+        }
+        return paint.fontMetrics().width(sampleText) + 13;
     } else {
         return std::max(paint.fontMetrics().width(tr("0dB")),
                         paint.fontMetrics().width(Strings::minus_infinity)) + 13;
@@ -1526,14 +1567,19 @@ WaveformLayer::paintVerticalScale(LayerGeometryProvider *v, bool, QPainter &pain
 
     double gain = m_gain;
 
+    int n = 10;
+
+    std::vector<ScaleTickIntervals::Tick> linearTicks;
+    if (m_scale == LinearScale) {
+        linearTicks = ScaleTickIntervals::linear({ 0.0, 1.0 / gain, n });
+    }
+
     for (int ch = minChannel; ch <= maxChannel; ++ch) {
 
         int lastLabelledY = -1;
 
         if (ch < (int)m_effectiveGains.size()) gain = m_effectiveGains[ch];
-
-        int n = 10;
-
+        
         for (int i = 0; i <= n; ++i) {
 
             double val = 0.0, nval = 0.0;
@@ -1542,13 +1588,27 @@ WaveformLayer::paintVerticalScale(LayerGeometryProvider *v, bool, QPainter &pain
             switch (m_scale) {
                 
             case LinearScale:
-                val = (i * gain) / n;
-                text = QString("%1").arg(double(i) / n);
-                if (i == 0) text = "0.0";
-                else {
-                    nval = -val;
-                    if (i == n) text = "1.0";
+                if (in_range_for(linearTicks, i)) {
+                    val = linearTicks[i].value * gain;
+                    text = QString::fromUtf8(linearTicks[i].label.c_str());
+                    if (i != 0) {
+                        nval = -val;
+                    }
+                } else {
+                    val = linearTicks[0].value * gain;
+                    text = QString::fromUtf8(linearTicks[0].label.c_str());
                 }
+                    
+                /*
+                val = double(i) / n;
+                text = QString("%1").arg(double(i) / (gain * n), 0, 'g', 2);
+//                if (i == 0) text = "0.0";
+//                else {
+                if (i != 0) {
+                    nval = -val;
+//                    if (i == n) text = "1.0";
+                }
+                */
                 break;
 
             case MeterScale:
@@ -1599,7 +1659,9 @@ WaveformLayer::paintVerticalScale(LayerGeometryProvider *v, bool, QPainter &pain
                 } else {
                     ty += toff;
                 }
-                paint.drawText(tx, ty, text);
+                if (!(i == n && ch > 0)) {
+                    paint.drawText(tx, ty, text);
+                }
 
                 lastLabelledY = ty - toff;
 
@@ -1645,7 +1707,7 @@ WaveformLayer::toXml(QTextStream &stream,
                  "scale=\"%6\" "
                  "middleLineHeight=\"%7\" "
                  "aggressive=\"%8\" "
-                 "autoNormalize=\"%9\"")
+                 "%9")
         .arg(m_gain)
         .arg(m_showMeans)
         .arg(true) // Option removed, but effectively always on, so
@@ -1655,7 +1717,10 @@ WaveformLayer::toXml(QTextStream &stream,
         .arg(m_scale)
         .arg(m_middleLineHeight)
         .arg(m_aggressive)
-        .arg(m_autoNormalize);
+        .arg(QString("autoNormalize=\"%1\" "
+                     "oversampling=\"%2\"")
+             .arg(m_autoNormalize)
+             .arg(m_oversampling));
 
     SingleColourLayer::toXml(stream, indent, extraAttributes + " " + s);
 }
@@ -1694,6 +1759,11 @@ WaveformLayer::setProperties(const QXmlAttributes &attributes)
     bool autoNormalize = (attributes.value("autoNormalize") == "1" ||
                           attributes.value("autoNormalize") == "true");
     setAutoNormalize(autoNormalize);
+
+    bool oversampling = (attributes.value("oversampling") == "" ||
+                         attributes.value("oversampling") == "1" ||
+                         attributes.value("oversampling") == "true");
+    setShowOversampledLines(oversampling);
 }
 
 int
